/*
  gpsdialog.cpp
  Copyright (C) 2008 Tomohiro Masubuchi <bucchi@e-ml.jp>

  This file is part of qgmap.

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; If not, see <http://www.gnu.org/licenses/>.
*/

#include "gpsdialog.h"
#include "mainwindow.h"
#include <qlayout.h>
#include <qgrid.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qstring.h>
#include <qspinbox.h>
#include <qhbox.h>
#include <qpushbutton.h>
#include <qbuttongroup.h>
#include <qradiobutton.h>
#include <qcombobox.h>

#define DIALOG_WIDTH  300
#define DIALOG_HEIGHT 150


GpsDialog::GpsDialog( QWidget* parent, const char* name,
						  bool modal, WFlags fl)
	: QDialog( parent, name, modal, fl )
{
    resize( QSize(DIALOG_WIDTH, DIALOG_HEIGHT).expandedTo(minimumSizeHint()) );

	setCaption(QString::fromUtf8("GPS設定"));
	setFont(QFont("lcfont", 16));

	QVBoxLayout *base_vbox = new QVBoxLayout(this);
	QGrid *grid = new QGrid(2, this);
	grid->setSpacing(3);

	new QLabel(QString::fromUtf8("GPS Device:"), grid);
	device = new QLineEdit(grid);

	new QLabel(QString::fromUtf8("PreCommand:"), grid);
	preCommand = new QLineEdit(grid);

	new QLabel(QString::fromUtf8("PostCommand:"), grid);
	postCommand = new QLineEdit(grid);

	new QLabel(QString::fromUtf8("更新間隔:"), grid);
	interval = new QSpinBox(1, 10, 1, grid);

	new QLabel(QString::fromUtf8("測地系:"), grid);
	QButtonGroup *datum = new QButtonGroup(2, Qt::Horizontal, grid);
	datum->setFrameStyle(QFrame::NoFrame);
	datum->setMargin(0);
	tokyo_datum = new QRadioButton(QString::fromUtf8("Tokyo"), datum);
	wgs84_datum = new QRadioButton(QString::fromUtf8("WGS84"), datum);
	wgs84_datum->setChecked(true);

	new QLabel(QString::fromUtf8("時差:"), grid);
	tz = new QComboBox(grid);
	for(int i = 14; i>= -11; i--){
		QString str;

		str.sprintf("UTC%+d", i);
		tz->insertItem(str);
	}

	base_vbox->addWidget(grid);

#ifndef QWS
	QHBox *hbox = new QHBox(this);
	QPushButton *cancel = new QPushButton("Cancel", hbox);
	QPushButton *ok = new QPushButton("OK", hbox);
	ok->setDefault(true);

	connect(cancel, SIGNAL(clicked()),
			this, SLOT(reject()));
	connect(ok, SIGNAL(clicked()),
			this, SLOT(accept()));

	base_vbox->addWidget(hbox);
#endif
}

GpsDialog::~GpsDialog()
{
}

void GpsDialog::setDevice(QString const &file)
{
	device->setText(file);
}

void GpsDialog::setPreCommand(QString const &cmd)
{
	preCommand->setText(cmd);
}

void GpsDialog::setPostCommand(QString const &cmd)
{
	postCommand->setText(cmd);
}

void GpsDialog::setInterval(int interval)
{
	this->interval->setValue(interval);
}

void GpsDialog::setDatum(GpsDialog::Datum datum)
{
	switch(datum){
	case Tokyo:
		tokyo_datum->setChecked(true);
		break;
	case WGS84:
		wgs84_datum->setChecked(true);
		break;
	}
}

void GpsDialog::setTimeZone(int timezone)
{
	tz->setCurrentItem(14-timezone);
}

QString GpsDialog::getDevice(void)
{
	return device->text();
}

QString GpsDialog::getPreCommand(void)
{
	return preCommand->text();
}

QString GpsDialog::getPostCommand(void)
{
	return postCommand->text();
}

int GpsDialog::getInterval(void)
{
	return interval->text().toInt();
}

GpsDialog::Datum GpsDialog::getDatum(void)
{
	return tokyo_datum->isChecked()?Tokyo:WGS84;
}

int GpsDialog::getTimeZone(void)
{
	return 14 - tz->currentItem();
}
