/*
  gpsindicator.cpp
  Copyright (C) 2008 Tomohiro Masubuchi <bucchi@e-ml.jp>

  This file is part of qgmap.

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; If not, see <http://www.gnu.org/licenses/>.
*/

#include "qgmap.h"
#include "gpsindicator.h"
#include <qframe.h>
#include <qlayout.h>
#include <qfont.h>
#include <qhbox.h>
#include <qlabel.h>
#include <qimage.h>

GPSIndicator::GPSIndicator(QWidget *parent, const char *name, WFlags f) :
	QFrame(parent, name, f)
{
#ifdef QWS
	setFont(QFont("lcfont", 12));
#else
	setFont(QFont("gothic", 8));
#endif

	QVBoxLayout *vbox = new QVBoxLayout(this, 2);
	setFrameStyle(QFrame::Box | QFrame::Plain);

	QHBox *hbox = new QHBox(this);
	hbox->setSpacing(3);

	icon = new QLabel(hbox);
	icon->setPixmap(QPixmap(APP_PATH "/satellite.png"));
	satellites = new QLabel(":--",hbox);
	time = new QLabel("--:--:--",hbox);
	hbox->setStretchFactor(time, 1);
	vbox->addWidget(hbox);

	lat = new QLabel("Lat:  --.------",this);
	lon = new QLabel("Lon: ---.------",this);
	vbox->addWidget(lat);
	vbox->addWidget(lon);

	disableText(true);
	adjustSize();
	setGeometry(30, 100, width(), height());

	interval = 3;
	tid = -1;
}

void GPSIndicator::show()
{
	QFrame::show();
	tid = startTimer(interval * 1000);

	satellites->setText(":--");
	time->setText("--:--:--");
	lat->setText("Lat:  --.------");
	lon->setText("Lon: ---.------");

	disableText(true);

	adjustSize();
	QWidget::show();
}

void GPSIndicator::hide()
{
	killTimers();
	tid = -1;
	QFrame::hide();
}

void GPSIndicator::updateInfo(GPSInfo &info)
{
	QString tmp;

	tmp.sprintf("Lat: %10.6f", info.getLatitude());
	lat->setText(tmp);
	tmp.sprintf("Lon:%11.6f", info.getLongitude());
	lon->setText(tmp);
	tmp.sprintf(":%d", info.getSatellites());
	satellites->setText(tmp);
	tmp = info.getDateTime().time().toString();
	time->setText(tmp);

	killTimer(tid);
	tid = startTimer(interval * 1000);

	disableText(false);
}

void GPSIndicator::timerEvent(QTimerEvent *e)
{
	killTimer(e->timerId());
	tid = -1;

	disableText(true);
	repaint();
}

void GPSIndicator::setInterval(int sec)
{
	interval = sec;
	if(tid >= 0){
		killTimer(tid);
		tid = startTimer(interval * 1000);
	}
}

void GPSIndicator::disableText(bool b)
{
	lat->setDisabled(b);
	lon->setDisabled(b);
	satellites->setDisabled(b);
	time->setDisabled(b);
}
