/*
  gpsview.cpp
  Copyright (C) 2008 Tomohiro Masubuchi <bucchi@e-ml.jp>

  This file is part of qgmap.

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; If not, see <http://www.gnu.org/licenses/>.
*/

#include "qgmap.h"
#include "gpsview.h"
#include "layeredbase.h"
#include "mainwindow.h"
#include "pos.h"
#include <qpixmap.h>
#include <qmessagebox.h>

GPSView::GPSView(LayeredBase *parent, const char *name) :
	LayeredWidget(parent, name)
{
	gps_on = false;
#ifdef QWS
	logger.setDeviceFile("/dev/rfcomm0");
#else
	logger.setDeviceFile("pipe");
#endif

	indicator = new GPSIndicator(parentWidget());
	indicator->setGeometry(10, 30, indicator->width(), indicator->height());
	indicator->hide();

	interval = 1;
	tid = -1;
}

bool GPSView::paintEvent(QPaintEvent *e UNUSED, QPixmap &scr UNUSED)
{
	return false;
}

bool GPSView::keyPressEvent(QKeyEvent *e)
{
	if(e->key() == Key_G){
		gps_on = !gps_on;
		if(gps_on){
			if(logger.start()){
				QMessageBox::critical(parentWidget(), "Error!!",
									  logger.getErrmsg());
				gps_on = false;
				return true;
			}
			tid = startTimer(interval * 1000); // 1s timer
			indicator->show();
		}else{
			killTimer(tid);
			tid = -1;
			logger.stop();
			indicator->hide();
		}
		return true;
	}
	return false;
}

void GPSView::showEvent()
{
}

void GPSView::timerEvent(QTimerEvent *e)
{
	if(!logger.isLive()){
		QMessageBox::critical(parentWidget(), "Error!!",
							  logger.getErrmsg());
		gps_on = false;
		logger.stop();
		indicator->hide();
	}

	if(!gps_on){
		killTimer(e->timerId());
		tid = -1;
		return;
	}

	GPSInfo info = logger.getInfo();
	if(!info.isUpdated())
		return;

	if(datum == GpsDialog::Tokyo){
		info.convTokyoToWGS();
	}
	info.setTimeZone(timezone);

	indicator->updateInfo(info);
	Pos pos(info.getLatitude(), info.getLongitude(), zoom);

	emit detectGPSPosition(pos);

/*
	printf("time:%s lat:%lf lon:%lf\n",
		   info.getTime().toString().ascii(),
		   info.getLatitude(),
		   info.getLongitude());
*/
}

void GPSView::setPosition(Pos &pos)
{
	zoom = pos.getZoom();
}

void GPSView::setConfig(const QString &key, const QString &value)
{
	if(key=="GPSDev"){
		logger.setDeviceFile(value);
	} else if(key=="PreCommand"){
		logger.setInitCommand(value);
	} else if(key=="PostCommand"){
		logger.setEndCommand(value);
	} else if(key=="GPSInterval"){
		interval = value.toInt();
		if(tid >= 0){
			killTimer(tid);
			tid = startTimer(interval * 1000);
		}
		indicator->setInterval(interval*3);
	} else if(key=="GPSDatum"){
		datum = (GpsDialog::Datum)value.toInt();
	} else if(key=="GPSTimeZone"){
		timezone = value.toInt();
	}
}
