/*
  iconmenu.cpp
  Copyright (C) 2008 Tomohiro Masubuchi <bucchi@e-ml.jp>

  This file is part of qgmap.

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; If not, see <http://www.gnu.org/licenses/>.
*/

#include <qpainter.h>
#include <qimage.h>
#include <qbitmap.h>
#include <qcursor.h>

#include "qgmap.h"
#include "mainwindow.h"
#include "iconmenu.h"
#include "dirdialog.h"
#include "gammadialog.h"
#include "gpsdialog.h"

IconMenu::IconMenu(LayeredBase *parent, const char *name) :
	LayeredWidget(parent, name)
{
	icon.load(MENUIMG_FILE);
	setGeometry(10,10, icon.width(), icon.height());

	popup_menu.insertItem("Map Path", this, SLOT(menu_activated(int)),0,MENU_MAPPATH);
	popup_menu.insertItem("Gamma", this, SLOT(menu_activated(int)),0,MENU_GAMMA);
	popup_menu.insertItem("GPS Settings", this, SLOT(menu_activated(int)),0,MENU_GPS);
}

bool IconMenu::paintEvent(QPaintEvent *e UNUSED, QPixmap &scr)
{
	QPainter p(&scr);
	p.drawPixmap(10, 10, icon);
	return true;
}

bool IconMenu::mousePressEvent( QMouseEvent *e )
{
	if(e->button() == LeftButton)
		popup_menu.popup(QCursor::pos());

	return false;
}

void IconMenu::menu_activated(int id)
{
	int ret;

	switch(id){
	case MENU_MAPPATH:
	{
		DirDialog dir(parentWidget(), QString::fromUtf8("Select 'imgs' path in GM_Lite"));

		dir.setPath(((MainWindow *)parentWidget())->getConfig("MapPath", DEFAULT_MAP_PATH));

		ret = dir.exec();
		if(ret == QDialog::Accepted){
			((MainWindow *)parentWidget())->setConfig("MapPath", dir.getPath());
		}
		break;
	}
	case MENU_GAMMA:
	{
		GammaDialog dlg(parentWidget(), "Gamma", TRUE);

		QString gamma = ((MainWindow *)parentWidget())->getConfig("Gamma", DEFAULT_GAMMA);
		dlg.setDefault(gamma.toDouble());

		ret = dlg.exec();
		if(ret == QDialog::Accepted){
			((MainWindow *)parentWidget())->setConfig("Gamma", QString::number(dlg.getGamma()));
		}
		break;
	}
	case MENU_GPS:
	{
		GpsDialog dlg(parentWidget(), "GPS", TRUE);

		dlg.setDevice(((MainWindow *)parentWidget())->getConfig("GPSDev", DEFAULT_GPS_DEVICE));
		dlg.setPreCommand(((MainWindow *)parentWidget())->getConfig("PreCommand", DEFAULT_PRE_COMMAND));
		dlg.setPostCommand(((MainWindow *)parentWidget())->getConfig("PostCommand", DEFAULT_POST_COMMAND));
		dlg.setInterval(((MainWindow *)parentWidget())->getNumConfig("GPSInterval", DEFAULT_GPS_INTERVAL));
		dlg.setDatum((GpsDialog::Datum)((MainWindow *)parentWidget())->getNumConfig("GPSDatum", DEFAULT_GPS_DATUM));
		dlg.setTimeZone(((MainWindow *)parentWidget())->getNumConfig("GPSTimeZone", DEFAULT_GPS_TIMEZONE));

		ret = dlg.exec();
		if(ret == QDialog::Accepted){
			((MainWindow *)parentWidget())->setConfig("GPSDev", dlg.getDevice());
			((MainWindow *)parentWidget())->setConfig("PreCommand", dlg.getPreCommand());
			((MainWindow *)parentWidget())->setConfig("PostCommand", dlg.getPostCommand());
			((MainWindow *)parentWidget())->setConfig("GPSInterval", dlg.getInterval());
			((MainWindow *)parentWidget())->setConfig("GPSDatum", dlg.getDatum());
			((MainWindow *)parentWidget())->setConfig("GPSTimeZone", dlg.getTimeZone());
		}
		break;
	}
	}
}
